# История изменений
Все изменения проекта должны быть отражены в этом файле.

Формат основан на [Keep a Changelog](http://keepachangelog.com/)
и проект следует [Семантическому версионированию](http://semver.org/).

## [x.y.z] - гггг-мм-дд
 
Здесь должно быть расширенное описание того, что было сделано, какие есть планы у команды по дальнейшему развитию. 
Желательно будущие цели привязывать к конкретным задачам. Т.е. на каждую цель нужно поставить отдельную задачу и 
отразить ее номер здесь.
 
### Добавлено
- [ПРОЕКТ-ZZZZ](https://jira.bars.group/browse/ПРОЕКТ-ZZZZ)
  PATCH Название задачи или изменения.

- [ПРОЕКТ-YYYY](https://jira.bars.group/browse/ПРОЕКТ-YYYY)
  MINOR Название задачи или изменения.

- [ПРОЕКТ-XXXX](https://jira.bars.group/browse/ПРОЕКТ-XXXX)
  MAJOR Название задачи или изменения.
 
### Изменено
 
### Исправлено


## [0.4.1] - 2023-08-09
 
Доработки для реализации принудительного выполнения функций экспорта данных сущностей.
 
### Добавлено

- [EDUSCHL-20235](https://jira.bars.group/browse/EDUSCHL-20235)
  PATCH Доработки для реализации принудительного выполнения функций экспорта данных сущностей.
 
### Изменено
 
### Исправлено


## [0.4.0] - 2023-08-09
 
Реализованы общие классы для команд сбора/экспорта.
 
### Добавлено
- [EDUSCHL-20200](https://jira.bars.group/browse/EDUSCHL-20200)
  MINOR Добавлены общие модели, методы и классы.
 
### Изменено
- [EDUSCHL-20200](https://jira.bars.group/browse/EDUSCHL-20200)
  MINOR Реализованы общие классы для команд сбора/экспорта.
 
### Исправлено


## [0.3.3] - 2023-08-08
 
Добавлено принудительное выполнение функций в ранере для экономии памяти.
 
### Добавлено
 
### Изменено
 
### Исправлено

- [EDUSCHL-20235](https://jira.bars.group/browse/EDUSCHL-20235)
  PATCH Добавлено принудительное выполнение функций в ранере для экономии памяти.


## [0.3.2] - 2023-08-08
 
Откат к спискам необработанных логов. Исправлена ошибка бесконечного создания чанков логов.
 
### Добавлено
 
### Изменено
 
### Исправлено

- [EDUSCHL-20235](https://jira.bars.group/browse/EDUSCHL-20235)
  PATCH Откат к спискам необработанных логов.


## [0.3.1] - 2023-08-08
 
Организована передача необработанных логов в виде генератора.
 
### Добавлено
 
### Изменено

- [EDUSCHL-20235](https://jira.bars.group/browse/EDUSCHL-20235)
  PATCH Организована передача необработанных логов в виде генератора.
 
### Исправлено


## [0.3.0] - 2023-08-06
 
Добавление функциональности для отложенного заполнения кешей. Заполнение производится перед началом работы запускаемого
объекта.
 
### Добавлено

- [EDUSCHL-20235](https://jira.bars.group/browse/EDUSCHL-20235)
  PATCH Добавлено отложенное заполнение кешей хелперов функций.

- [EDUSCHL-20235](https://jira.bars.group/browse/EDUSCHL-20235)
  MINOR Добавлено проставление подэтапа выгрузки данных у записей моделей.
 
### Изменено
 
### Исправлено


## [0.2.2] - 2023-08-06

Для API РВД добавлена поддержка параметра типа операции для загрузки данных.

### Добавлено

- [EDUSCHL-19920](https://jira.bars.group/browse/EDUSCHL-19920)
  PATCH Для API РВД добавлена поддержка параметра типа операции для загрузки данных.


## [0.2.1] - 2023-08-05
 
Восстановление сборки пакета после ухода с poetry.
 
### Добавлено
 
### Изменено
 
### Исправлено

- [EDUSCHL-19919](https://jira.bars.group/browse/EDUSCHL-19919)
  PATCH Восстановление сборки пакета после миграции с poetry.


## [0.2.0] - 2023-08-04

Перенос стратегий формирования Функций используемых в генерации исходников.
 
### Добавлено

- [EDUSCHL-19919](https://jira.bars.group/browse/EDUSCHL-19919)
  MINOR Перенесены стратегии создания Функций из ЭШ.

 
### Изменено
 
### Исправлено


## [0.1.4] - 2023-08-03
 
Возвращение ранее удаленных зависимостей миграции
 
### Добавлено

### Изменено

- [EDUSCHL-20209](https://jira.bars.group/browse/EDUSCHL-20209)
  PATCH Возвращение зависимостей миграции.

- [EDUSCHL-20209](https://jira.bars.group/browse/EDUSCHL-20209)
  PATCH Доработки по формированию документации.

- [EDUSCHL-20200](https://jira.bars.group/browse/EDUSCHL-20200)
  Закреплены версии зависимостей, добавлена ссылка на uploader-client
 
### Исправлено



## [0.1.3] - 2023-07-24
 
Для раскатки миграций на ЭШ, пришлось закомментировать зависимости в initial-миграции. 
 
### Добавлено
 
### Изменено

- [EDUSCHL-19919](https://jira.bars.group/browse/EDUSCHL-19919)
  PATCH Вынести общую часть для работы с РВД из ЭШ для использования в ЭК.
 
### Исправлено

## [0.1.2] - 2023-07-23

Внесены изменения в кодовую базу после переноса механизма логирования из ЭШ в educommon.

### Добавлено

### Изменено

- [EDUSCHL-19919](https://jira.bars.group/browse/EDUSCHL-19919)
  PATCH Вынести общую часть для работы с РВД из ЭШ для использования в ЭК.

### Исправлено


## [0.1.0] - 2023-07-18

Внесены изменения в кодовую базу после переноса механизма логирования из ЭШ в educommon.

### Добавлено

- [EDUSCHL-19919](https://jira.bars.group/browse/EDUSCHL-19919)
  MINOR Перенос базовых компонентов интеграции с РВД из ЭШ.

### Изменено

### Исправлено
